==> acl2_8.3dfsg.orig.tar.gz: acl2-8.3dfsg/books/rtl/rel11/lib/top-doc.lisp <==
; Copyright (C) 2018 Centaur Technology
;
; Contact:
;   Centaur Technology Formal Verification Group
;   7600-C N. Capital of Texas Highway, Suite 300, Austin, TX 78731, USA.
;   http://www.centtech.com/
;
; License: (An MIT/X11-style license)
;
;   Permission is hereby granted, free of charge, to any person obtaining a
;   copy of this software and associated documentation files (the "Software"),
;   to deal in the Software without restriction, including without limitation
;   the rights to use, copy, modify, merge, publish, distribute, sublicense,
;   and/or sell copies of the Software, and to permit persons to whom the
;   Software is furnished to do so, subject to the following conditions:
;
;   The above copyright notice and this permission notice shall be included in
;   all copies or substantial portions of the Software.
;
;   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
;   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
;   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
;   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
;   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
;   FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
;   DEALINGS IN THE SOFTWARE.
;
; Original author (this file): Sol Swords <sswords@centtech.com>

(in-package "RTL")

(include-book "xdoc/archive-matching-topics" :dir :system)

(local
 (progn
   (include-book "rtl/rel11/lib/top" :dir :system)
; And books not included in lib/top:
   (include-book "rtl/rel11/lib/add" :dir :system)
   (include-book "rtl/rel11/lib/mult" :dir :system)
   (include-book "rtl/rel11/lib/div" :dir :system)
   (include-book "rtl/rel11/lib/srt" :dir :system)
   (include-book "rtl/rel11/lib/sqrt" :dir :system)))

(xdoc::archive-matching-topics
 (str::strprefixp "[books]/rtl/" (cdr (assoc :from x))))

==> acl2_8.6+dfsg.orig.tar.gz: acl2-8.6+dfsg/books/rtl/rel11/lib/top-doc.lisp <==
; Copyright (C) 2018 Centaur Technology
;
; Contact:
;   Centaur Technology Formal Verification Group
;   7600-C N. Capital of Texas Highway, Suite 300, Austin, TX 78731, USA.
;   http://www.centtech.com/
;
; License: (An MIT/X11-style license)
;
;   Permission is hereby granted, free of charge, to any person obtaining a
;   copy of this software and associated documentation files (the "Software"),
;   to deal in the Software without restriction, including without limitation
;   the rights to use, copy, modify, merge, publish, distribute, sublicense,
;   and/or sell copies of the Software, and to permit persons to whom the
;   Software is furnished to do so, subject to the following conditions:
;
;   The above copyright notice and this permission notice shall be included in
;   all copies or substantial portions of the Software.
;
;   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
;   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
;   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
;   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
;   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
;   FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
;   DEALINGS IN THE SOFTWARE.
;
; Original author (this file): Sol Swords <sswords@centtech.com>

(in-package "RTL")

(include-book "xdoc/archive-matching-topics" :dir :system)

(local
 (progn
   (include-book "rtl/rel11/lib/top" :dir :system)
; And books not included in lib/top:
   (include-book "rtl/rel11/lib/add" :dir :system)
   (include-book "rtl/rel11/lib/mult" :dir :system)
   (include-book "rtl/rel11/lib/div" :dir :system)
   (include-book "rtl/rel11/lib/srt" :dir :system)
   (include-book "rtl/rel11/lib/sqrt" :dir :system)))

(xdoc::archive-matching-topics
 (str::strprefixp "rtl/" (cdr (assoc :from x))))
